@@ -179,6 +179,12 @@ TEST(gncnumeric_constructors, test_string_constructor)
                  std::out_of_range);
     EXPECT_THROW(GncNumeric bad_string("Four score and seven"),
                  std::invalid_argument);
+    GncNumeric neg_decimal_frac("-0.12345");
+    EXPECT_EQ(-12345, neg_decimal_frac.num());
+    EXPECT_EQ(100000, neg_decimal_frac.denom());
+    GncNumeric neg_decimal_frac_nozero("-.12345");
+    EXPECT_EQ(-12345, neg_decimal_frac_nozero.num());
+    EXPECT_EQ(100000, neg_decimal_frac_nozero.denom());
 }
 
 TEST(gncnumeric_output, string_output)
@@ -542,4 +548,16 @@ TEST(gnc_numeric_functions, test_conversion_to_decimal)
     EXPECT_NO_THROW(r = c.to_decimal());
     EXPECT_EQ(27434842, r.num());
     EXPECT_EQ(100, r.denom());
+    GncNumeric d(11900000000, 85000000);
+    EXPECT_NO_THROW(r = d.to_decimal());
+    EXPECT_EQ(140, r.num());
+    EXPECT_EQ(1, r.denom());
+    GncNumeric e(11050000000, 65000000);
+    EXPECT_NO_THROW(r = e.to_decimal());
+    EXPECT_EQ(170, r.num());
+    EXPECT_EQ(1, r.denom());
+    GncNumeric f(5000000000, 50000000 );
+    EXPECT_NO_THROW(r = f.to_decimal());
+    EXPECT_EQ(100, r.num());
+    EXPECT_EQ(1, r.denom());
 }
